package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.SysRotograph;
import com.ruoyi.system.domain.vo.FilleVo;

/**
 * 轮播图附件Service接口
 * 
 * @author ruoyi
 * @date 2023-02-24
 */
public interface ISysRotographService 
{
    /**
     * 查询轮播图附件
     * 
     * @param id 轮播图附件主键
     * @return 轮播图附件
     */
    public SysRotograph selectSysRotographById(Long id);

    /**
     * 查询轮播图附件列表
     * 
     * @param sysRotograph 轮播图附件
     * @return 轮播图附件集合
     */
    public List<SysRotograph> selectSysRotographList(SysRotograph sysRotograph);

    /**
     * 新增轮播图附件
     * 
     * @param sysRotograph 轮播图附件
     * @return 结果
     */
    public int insertSysRotograph(SysRotograph sysRotograph);

    /**
     * 修改轮播图附件
     * 
     * @param sysRotograph 轮播图附件
     * @return 结果
     */
    public int updateSysRotograph(SysRotograph sysRotograph);

    /**
     * 批量删除轮播图附件
     * 
     * @param ids 需要删除的轮播图附件主键集合
     * @return 结果
     */
    public int deleteSysRotographByIds(Long[] ids);

    /**
     * 删除轮播图附件信息
     * 
     * @param id 轮播图附件主键
     * @return 结果
     */
    public int deleteSysRotographById(Long id);
}
